@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 
 from codetalker import pgm
-from codetalker.pgm.tokens import STRING, ID, NUMBER, WHITE, NEWLINE, ReToken, re
-from codetalker.pgm.special import star, plus, _or, expand, binop
+from codetalker.pgm.tokens import STRING, ID, NUMBER, WHITE, NEWLINE, ReToken, re, CharToken, StringToken
+from codetalker.pgm.special import star, plus, _or, binop
 from codetalker.pgm.grammar import ParseError
 
 ## TOKENS
@@ -10,9 +10,17 @@ from codetalker.pgm.grammar import ParseError
 class OP(ReToken):
     rx = re.compile('\\*\\*|[-+*/%]')
 
+class OP(StringToken):
+    strings = ['**', '[', '-', '+', '*', '/', '%']
+    num = 7
+
 class SYMBOL(ReToken):
     rx = re.compile('[()]')
 
+class SYMBOL(CharToken):
+    chars = '()'
+    num = 2
+
 ## RUlES
 
 '''order of operations:
@@ -26,7 +34,7 @@ class SYMBOL(ReToken):
 
 expression = binop(list('-+'), list('*/%'), ['**'], value=NUMBER, ops_token=OP, name='BinOp', paren=True)
 
-grammar = pgm.Grammar(start=expression, tokens = [OP, NUMBER, SYMBOL, WHITE, NEWLINE], ignore = [WHITE, NEWLINE], ast_tokens=[NUMBER])
+grammar = pgm.Grammar(start=expression, tokens = [SYMBOL, OP], ignore = [WHITE, NEWLINE], ast_tokens=[NUMBER])
 
 m = pgm.Translator(grammar)
 
@@ -36,15 +44,15 @@ import operator
 ops = {'**':operator.pow, '*':operator.mul, '/':operator.div, '%':operator.mod, '+':operator.add, '-':operator.sub}
 
 @m.translates(ast.BinOp)
-def binop(node, scope):
-    value = m.translate(node.left, scope)
+def binop(node):
+    value = m.translate(node.left)
     for op, right in zip(node.ops, node.values):
-        nv = m.translate(right, scope)
+        nv = m.translate(right)
         value = ops[op.value](value, nv)
     return value
 
 @m.translates(NUMBER)
-def number(node, scope):
+def number(node):
     return float(node.value)
 
 evaluate = m.from_string
